import { CronJob } from 'cron';
import Log from './Log.js';
import LogFmt from './LogFmt.js';

export default class Job {

  static Cron = CronJob;

  static EVERY_MINUTE = '*/1 * * * *';
  static TWO_MINUTES = '*/2 * * * *';
  static FIVE_MINUTES = '*/5 * * * *';
  static TEN_MINUTES = '*/10 * * * *';
  static QUARTER_HOUR = '*/15 * * * *';
  static HALF_HOUR = '*/30 * * * *';

  static ONE_HOUR = '0 * * * *';
  static TWO_HOURS = '0 */2 * * *';
  static THREE_HOURS = '0 */3 * * *';
  static SIX_HOURS = '0 */6 * * *';
  static TWELVE_HOURS = '0 */12 * * *';

  static ONE_DAY = '0 0 * * *';

  static start(cronTime, callback, description) {
    const job = new this.Cron(cronTime, async () => {
      await this._exec(callback, description)
    });
    job.start();

    if (description) {
      Log.log(
        LogFmt.msg('Adding cron job')
          .tag('cron-job')
          .string('job_name', description)
          .string('cron_time', cronTime)
          .log()
      );
    }

    return job;
  }

  static async _exec(cb, description) {
    if (description) {
      Log.debug(
        LogFmt.msg('Started cron job').tag('cron-job')
          .string('job_name', description).string('state', 'started')
          .log()
      );
    }

    const start = Date.now();
    await cb();
    const elapsed = Date.now() - start;

    if (description) {
      Log.info(
        LogFmt.msg('Finished cron job')
          .tag('cron-job')
          .string('job_name', description).string('state', 'finished')
          .decimal('elapsed_ms', elapsed, 2)
          .log()
      );
    }
  }

}
