import assert from 'assert';
import Cache from '../src/Cache.js';

describe('Cache.js', function() {

  describe('#constructor(cacheKey)', function() {

    it('create a new cache', function() {
      const key = 'testKey';
      const cache = new Cache(key);

      assert.deepEqual(cache.key, key);
      assert.deepEqual(cache.storage.size, 0);
      assert.deepEqual(cache._seconds, null);
      assert.deepEqual(cache._limit, null);
    });

  });

  describe('#add(key, value), #get(key), #delete(key)', function() {

    it('null value #get if does not exist', function() {
      const key = 'testKey';
      const cache = new Cache(key);

      assert.deepEqual(cache.get('noExist'), null);
    });

    it('#add the value, #get it, and #delete it', function() {
      const key = 'testKey';
      const cache = new Cache(key);
      cache.add('exist', 3);

      assert.deepEqual(cache.get('exist'), 3);

      cache.delete('exist');
      assert.deepEqual(cache.get('exist'), null);
    });

  });

  describe('#limit(limit)', function() {

    it('set the limit', function() {
      const key = 'testKey';
      const limit = 3;
      const cache = new Cache(key);
      cache.limit(limit);

      assert.deepEqual(cache._limit, limit);
      assert.deepEqual(cache.keysArray.limit, limit)
    });

  });
});


