import assert from 'assert';
import DateUtil from '../src/DateUtil.js';
import Language from '../src/Language.js';

describe('DateUtil.js', function() {

  describe('#getLocaleFromLanguageCode(languageCode)', function() {

    it('should return correctly the locale for the "es" value', function() {
      var languageCode = Language.SPANISH;

      var expected = 'es-ES';
      var result = DateUtil.getLocaleFromLanguageCode(languageCode);
      assert.deepStrictEqual(result, expected);
    });

    it('should return correctly the locale for the "en" value', function() {
      var languageCode = Language.ENGLISH;

      var expected = 'en-US';
      var result = DateUtil.getLocaleFromLanguageCode(languageCode);
      assert.deepStrictEqual(result, expected);
    });

  });

  describe('#isToday(date)', function() {

    it('TRUE when today is passed', function() {
      const today = new Date();
      assert.ok(DateUtil.isToday(today));
    });

    it('FALSE when yesterday is passed', function() {
      const yesterday = DateUtil.yesterday()
      assert.deepStrictEqual(DateUtil.isToday(yesterday), false);
    });

  });


  describe('#toLocaleDateString(date)', function() {

    it('properly get only the date for en-US', function() {
      const date = new Date('2022-03-01');
      const result = DateUtil.toLocaleDateString(date, 'en-US');
      const expected = '3/1/2022';
      assert.deepStrictEqual(expected, result);
    });

    it('properly get only the date for es-ES', function() {
      const date = new Date('2022-03-01');
      const result = DateUtil.toLocaleDateString(date, 'es-ES');
      const expected = '1/3/2022';
      assert.deepStrictEqual(expected, result);
    });

  });

});

