import assert from 'assert';
import Log from '../src/Log.js';
import LogFormat from '../src/LogFormat.js';
import LogLevel from '../src/LogLevel.js';

describe('Log.js', function() {

  describe('#_createCompleteLog(log, level)', function() {

    it('produces simple log', function() {
      Log.format(LogFormat.SIMPLE);

      var expected = "[INFO] - this is just a simple log";
      var result = Log._createCompleteLog("this is just a simple log");
      assert.deepStrictEqual(expected, result);
    });

    it('adds default level using log_fmt', function() {
      Log.format(LogFormat.LOG_FMT);
      var expected = 'level="info" name="test-log"';
      var result = Log._createCompleteLog('name="test-log"');
      assert.deepStrictEqual(expected, result);
    });


    it('adds debug level using log_fmt', function() {
      Log.format(LogFormat.LOG_FMT);
      var expected = 'level="debug" name="test-log"';
      var result = Log._createCompleteLog('name="test-log"', LogLevel.DEBUG);
      assert.deepStrictEqual(expected, result);
    });

    it('adds error level using log_fmt', function() {
      Log.format(LogFormat.LOG_FMT);
      var expected = 'level="error" name="test-log"';
      var result = Log._createCompleteLog('name="test-log"', LogLevel.ERROR);
      assert.deepStrictEqual(expected, result);
    });


    it('adds warn level using log_fmt', function() {
      Log.format(LogFormat.LOG_FMT);
      var expected = 'level="warn" name="test-log"';
      var result = Log._createCompleteLog('name="test-log"', LogLevel.WARN);
      assert.deepStrictEqual(expected, result);
    });

  });

});
